Learn R Programming

HaploVar (version 0.1.1)

collate_haplotype_variants: Collate haplotype_variants Tables

Description

This function collates a list of output files from haplotype_variants.

Usage

collate_haplotype_variants(haplotype_variants_list, format = 1)

Value

A collated table of haplotype variants.

Arguments

haplotype_variants_list

A list of the tables created by the define_haplotypes function.

format

The format you want the output table to be in. This should be the same number you used when running define_haplotypes.