collate_define_haplotypes: Collate define_haplotypes Lists
Description
This function collates a list of output files from define_haplotypes.
Usage
collate_define_haplotypes(haplotype_list)
Value
A collated list of all haplotype tables.
Arguments
- haplotype_list
A list of the lists created by the define_haplotypes function.