This function collates a list of output files from haplotype_variants.
collate_haplotype_variants(haplotype_variants_list, format = 1)A collated table of haplotype variants.
A list of the tables created by the define_haplotypes function.
The format you want the output table to be in. This should be the same number you used when running define_haplotypes.